from os import listdir
from os.path import isfile, join

import xml.etree.ElementTree as ET

from rb.docs_processing.article import Article
from rb.docs_processing.graph import Graph
from rb.core.lang import Lang



def parse_xml_file(file_path: str, graph: Graph) -> Article:
    tree = ET.parse(file_path)
    root = tree.getroot()

    abstract = root[0][0].text
    title = root[1][0].text
    date = root[1][1].text
    source = root[1][2].text
    authors = []
    for element in root[1][4]:
        authors.append(element.text)
    article = Article(title, abstract, source, authors, date, Lang.EN, graph)
    return article


def load_directory_xmls(directory_path: str) -> Graph:
    graph = Graph()
    for f in listdir(directory_path):
        if isfile(join(directory_path, f)):
            print(join(directory_path, f))
            parse_xml_file(join(directory_path, f), graph)
    return graph

# load_directory_xmls("C:\\Users\\Dragos\\Documents\\Facultate-Munca\\onlinedatasetexplorer\\AI_grub")




from rb.core.lang import Lang
from rb.core.document import Document

from rb.docs_processing.author import Author

from typing import List

import datetime


class Article:

    def __init__(self, title: str, abstract: str, source:str, authors: List[str], date: str, lang: Lang, graph: "Graph"):
        self.title = title
        self.abstract = abstract
        self.author_list = []
        
        for author_name in authors:
            if author_name:
                self.author_list.append(author_name)
                if not author_name in graph.authors_dict:
                    author = Author(author_name)
                    graph.authors_dict[author_name] = author
                    author.articles.add(self)
                else:
                    graph.authors_dict[author_name].articles.add(self)
        
        self.source = source
        self.date = datetime.datetime.strptime(date, "%d-%m-%Y")
        self.document = Document(lang, abstract)
        graph.articles_set.add(self)

    
    def __eq__(self, other):
        if isinstance(other, Article):
            return self.title == other.title
        return NotImplemented


    def __hash__(self):
        return hash(tuple(self.title))